@@ -6,7 +6,7 @@ no warnings;
 
 use Carp;
 
-our $VERSION = '0.102';
+our $VERSION = '0.103';
 
 =encoding utf8
 
@@ -150,15 +150,15 @@ Returns the CRC-32 checksum of the file.
 
 This source is in Github
 
-	git://github.com/briandfoy/file-fingerprint.git
+	https://github.com/briandfoy/file-fingerprint.git
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2008-2018, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2008-2024, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
 You may redistribute this under the terms of the Artistic License 2.0.
 
